;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ebdb-mua-sidecar" "20251029.1934"
  "EBDB Integration for Universal Sidecar."
  '((emacs             "28.1")
    (universal-sidecar "1.5.1")
    (ebdb              "0.8.20"))
  :url "https://git.sr.ht/~swflint/emacs-universal-sidecar"
  :commit "01b12aecca0ce66f5427e7fe65012d37e7e128b2"
  :revdesc "01b12aecca0c"
  :keywords '("mail" "convenience")
  :authors '(("Samuel W. Flint" . "me@samuelwflint.com"))
  :maintainers '(("Samuel W. Flint" . "me@samuelwflint.com")))
